"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.init = init;
exports.lastEventId = lastEventId;
exports.flush = flush;
exports.close = close;
exports.defaultIntegrations = void 0;

var tslib_1 = _interopRequireWildcard(require("tslib"));

var _core = require("@sentry/core");

var _hub = require("@sentry/hub");

var _utils = require("@sentry/utils");

var domain = _interopRequireWildcard(require("domain"));

var _client = require("./client");

var _integrations = require("./integrations");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

var defaultIntegrations = [// Common
new _core.Integrations.InboundFilters(), new _core.Integrations.FunctionToString(), // Native Wrappers
new _integrations.Console(), new _integrations.Http(), // Global Handlers
new _integrations.OnUncaughtException(), new _integrations.OnUnhandledRejection(), // Misc
new _integrations.LinkedErrors()];
/**
 * The Sentry Node SDK Client.
 *
 * To use this SDK, call the {@link init} function as early as possible in the
 * main entry module. To set context information or send manual events, use the
 * provided methods.
 *
 * @example
 * ```
 *
 * const { init } = require('@sentry/node');
 *
 * init({
 *   dsn: '__DSN__',
 *   // ...
 * });
 * ```
 *
 * @example
 * ```
 *
 * const { configureScope } = require('@sentry/node');
 * configureScope((scope: Scope) => {
 *   scope.setExtra({ battery: 0.7 });
 *   scope.setTag({ user_mode: 'admin' });
 *   scope.setUser({ id: '4711' });
 * });
 * ```
 *
 * @example
 * ```
 *
 * const { addBreadcrumb } = require('@sentry/node');
 * addBreadcrumb({
 *   message: 'My Breadcrumb',
 *   // ...
 * });
 * ```
 *
 * @example
 * ```
 *
 * const Sentry = require('@sentry/node');
 * Sentry.captureMessage('Hello, world!');
 * Sentry.captureException(new Error('Good bye'));
 * Sentry.captureEvent({
 *   message: 'Manual',
 *   stacktrace: [
 *     // ...
 *   ],
 * });
 * ```
 *
 * @see {@link NodeOptions} for documentation on configuration options.
 */

exports.defaultIntegrations = defaultIntegrations;

function init(options) {
  if (options === void 0) {
    options = {};
  }

  if (options.defaultIntegrations === undefined) {
    options.defaultIntegrations = defaultIntegrations;
  }

  if (options.dsn === undefined && process.env.SENTRY_DSN) {
    options.dsn = process.env.SENTRY_DSN;
  }

  if (options.release === undefined) {
    var global_1 = (0, _utils.getGlobalObject)(); // Prefer env var over global

    if (process.env.SENTRY_RELEASE) {
      options.release = process.env.SENTRY_RELEASE;
    } // This supports the variable that sentry-webpack-plugin injects
    else if (global_1.SENTRY_RELEASE && global_1.SENTRY_RELEASE.id) {
        options.release = global_1.SENTRY_RELEASE.id;
      }
  }

  if (options.environment === undefined && process.env.SENTRY_ENVIRONMENT) {
    options.environment = process.env.SENTRY_ENVIRONMENT;
  }

  if (domain.active) {
    (0, _hub.setHubOnCarrier)((0, _hub.getMainCarrier)(), (0, _core.getCurrentHub)());
  }

  (0, _core.initAndBind)(_client.NodeClient, options);
}
/**
 * This is the getter for lastEventId.
 *
 * @returns The last event id of a captured event.
 */


function lastEventId() {
  return (0, _core.getCurrentHub)().lastEventId();
}
/**
 * A promise that resolves when all current events have been sent.
 * If you provide a timeout and the queue takes longer to drain the promise returns false.
 *
 * @param timeout Maximum time in ms the client should wait.
 */


function flush(timeout) {
  return tslib_1.__awaiter(this, void 0, void 0, function () {
    var client;
    return tslib_1.__generator(this, function (_a) {
      client = (0, _core.getCurrentHub)().getClient();

      if (client) {
        return [2
        /*return*/
        , client.flush(timeout)];
      }

      return [2
      /*return*/
      , Promise.reject(false)];
    });
  });
}
/**
 * A promise that resolves when all current events have been sent.
 * If you provide a timeout and the queue takes longer to drain the promise returns false.
 *
 * @param timeout Maximum time in ms the client should wait.
 */


function close(timeout) {
  return tslib_1.__awaiter(this, void 0, void 0, function () {
    var client;
    return tslib_1.__generator(this, function (_a) {
      client = (0, _core.getCurrentHub)().getClient();

      if (client) {
        return [2
        /*return*/
        , client.close(timeout)];
      }

      return [2
      /*return*/
      , Promise.reject(false)];
    });
  });
}